import { DatasourceOptions } from '@genesislcap/foundation-comms';
import { JsonFormsState, OwnPropsOfControl, RankedTester, StatePropsOfControl } from '@jsonforms/core';
import { ViewTemplate } from '@microsoft/fast-element';
import { ErrorObject } from 'ajv';
import { DispatchRenderer } from './jsonforms/renderers/dispatch-renderer';
/** @public */
export type UiSchemaElementType = 'Control' | 'VerticalLayout' | any;
/** @public */
export type StepperOrientationType = 'vertical' | 'horizontal';
/** @public */
export type UiSchemaElementOptions = {
    async?: boolean;
    orientation?: StepperOrientationType;
    allOptionsResourceName?: string;
    datasourceConfig?: DatasourceOptions;
    hidden?: boolean;
    isPassword?: boolean;
    validateFn?: (data: any, path: string, label: string) => ErrorObject[];
    valueField?: string;
    labelField?: string;
    textarea?: boolean;
    data?: any[];
    childUiSchema?: UiSchema;
    childElements?: UiSchema[];
    i18n?: {
        [key: string]: any;
    };
};
/** @public */
export type UiSchemaElement = {
    type: UiSchemaElementType;
    scope: string;
    label?: string;
    placeholder?: string;
    options?: UiSchemaElementOptions;
};
/** @public */
export type UiSchema = {
    type: UiSchemaElementType;
    elements: UiSchemaElement[];
    dsPrefix?: string;
    options?: UiSchemaElementOptions;
};
/** @public */
export type RendererEntry = {
    renderer: ViewTemplate<DispatchRenderer, any>;
    tester: RankedTester;
    mapper: (state: JsonFormsState, ownProps: OwnPropsOfControl) => StatePropsOfControl;
};
//# sourceMappingURL=types.d.ts.map